ekiga r6410 - in trunk: lib/gmconf src/gui
- From: jpuydt svn gnome org
- To: svn-commits-list gnome org
- Subject: ekiga r6410 - in trunk: lib/gmconf src/gui
- Date: Sat, 28 Jun 2008 11:57:17 +0000 (UTC)
Author: jpuydt
Date: Sat Jun 28 11:57:17 2008
New Revision: 6410
URL: http://svn.gnome.org/viewvc/ekiga?rev=6410&view=rev
Log:
Added a proper shutdown api to the gmconf system, and made use of it.
Modified:
trunk/lib/gmconf/gmconf.h
trunk/src/gui/main.cpp
Modified: trunk/lib/gmconf/gmconf.h
==============================================================================
--- trunk/lib/gmconf/gmconf.h (original)
+++ trunk/lib/gmconf/gmconf.h Sat Jun 28 11:57:17 2008
@@ -78,6 +78,7 @@
* case it only saves things every now and then (this is the case of the glib
* implementation, for example) */
void gm_conf_init (); /* don't try anything before! */
+void gm_conf_shutdown (); /* don't try anything after! */
void gm_conf_save (); /* to forcibly save */
/* to accept/refuse that the notifiers get fired:
Modified: trunk/src/gui/main.cpp
==============================================================================
--- trunk/src/gui/main.cpp (original)
+++ trunk/src/gui/main.cpp Sat Jun 28 11:57:17 2008
@@ -4444,8 +4444,9 @@
/* Exit Ekiga */
GnomeMeeting::Process ()->Exit ();
/* Save the configuration */
gm_conf_save ();
+ gm_conf_shutdown ();
#ifdef HAVE_GNOME
g_object_unref (program);
[
@@ -4444,8 +4444,9 @@
/* Exit Ekiga */
GnomeMeeting::Process ()->Exit ();
- /* Save the configuration */
+ /* Save and shutdown the configuration */
gm_conf_save ();
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]